<?php

namespace Drupal\static_node\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\node\NodeInterface;
use Drupal\static_node\StaticNodeHooks;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a confirmation form for regenerating a static file.
 */
class StaticFileRegenerateForm extends ConfirmFormBase {

  /**
   * The static node hooks service.
   *
   * @var \Drupal\static_node\StaticNodeHooks
   */
  protected $staticNodeHooks;

  /**
   * The node entity.
   *
   * @var \Drupal\node\NodeInterface
   */
  protected $node;

  /**
   * Constructs a StaticFileRegenerateForm object.
   *
   * @param \Drupal\static_node\StaticNodeHooks $static_node_hooks
   *   The static node hooks service.
   */
  public function __construct(StaticNodeHooks $static_node_hooks) {
    $this->staticNodeHooks = $static_node_hooks;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('static_node.hooks')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'static_node_regenerate_confirm_form';
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Are you sure you want to regenerate the static HTML file for %title?', ['%title' => $this->node->getTitle()]);
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return Url::fromRoute('static_node.files_management');
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription() {
    return $this->t('This will regenerate the static HTML file for this node, overwriting the existing one.');
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return $this->t('Regenerate Static File');
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelText() {
    return $this->t('Cancel');
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, NodeInterface $node = NULL) {
    $this->node = $node;
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Regenerate the static version (which automatically removes the old one first)
    $form_state->set('node', $this->node);
    $this->staticNodeHooks->generateStaticVersion($form, $form_state);
    
    // Redirect to the files management page
    $form_state->setRedirectUrl(Url::fromRoute('static_node.files_management'));
  }

}
