<?php

namespace Drupal\static_node\Plugin\Action;

use Drupal\Core\Action\ActionBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\static_node\StaticNodeHooks;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Messenger\MessengerInterface;

/**
 * Action description.
 *
 * @Action(
 *   id = "static_node_generate_action",
 *   label = @Translation("Generate static page"),
 *   type = "node",
 *   category = @Translation("Content")
 * )
 */
class StaticNodeGenerateAction extends ActionBase implements ContainerFactoryPluginInterface {

  /**
   * The static node hooks service.
   *
   * @var \Drupal\static_node\StaticNodeHooks
   */
  protected $staticNodeHooks;

  /**
   * The messenger service.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * Constructs a new StaticNodeGenerateAction object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin ID for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\static_node\StaticNodeHooks $static_node_hooks
   *   The static node hooks service.
   * @param \Drupal\Core\Messenger\MessengerInterface $messenger
   *   The messenger service.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, StaticNodeHooks $static_node_hooks, MessengerInterface $messenger) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->staticNodeHooks = $static_node_hooks;
    $this->messenger = $messenger;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('static_node.hooks'),
      $container->get('messenger')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function executeMultiple(array $entities) {
    $form = [];
    $form_state = new \Drupal\Core\Form\FormState();
    
    foreach ($entities as $entity) {
      // Set the node in the form state for use by generateStaticVersion
      $form_state->set('node', $entity);
      
      // Generate the static version
      $this->staticNodeHooks->generateStaticVersion($form, $form_state);
    }
    
    $this->messenger->addMessage($this->t('Generated static pages for @count content items.', ['@count' => count($entities)]));
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function execute($entity = NULL) {
    $this->executeMultiple([$entity]);
    return true;
  }

  /**
   * {@inheritdoc}
   */
  public function access($object, AccountInterface $account = NULL, $return_as_object = FALSE) {
    /** @var \Drupal\node\NodeInterface $object */
    $access = $object->access('update', $account, TRUE)
      ->andIf($object->access('view', $account, TRUE));

    return $return_as_object ? $access : $access->isAllowed();
  }

}